@@ -3,12 +3,15 @@ from django.contrib import admin
 from .models import Log, Service, Notification
 from ftp_deploy.server.forms import NotificationForm, ServiceForm
 
+
 class ServiceAdmin(admin.ModelAdmin):
     form = ServiceForm
-    list_display = ('repo_name', 'repo_branch', 'hook_url', 'status_message_html', 'status')
+    list_display = ('repo_name', 'repo_branch', 'hook_url',
+                    'status_message_html', 'status')
     fieldsets = (
         ('FTP Settings', {
-            'fields': ('ftp_host', ('ftp_username', 'ftp_password'), 'ftp_path')
+            'fields': ('ftp_host', ('ftp_username', 'ftp_password'),
+                       'ftp_path')
         }),
         ('Repository', {
             'classes': ('',),
@@ -32,7 +35,8 @@ class ServiceAdmin(admin.ModelAdmin):
 
 class LogAdmin(admin.ModelAdmin):
     list_display = ('id', 'created', 'user', 'status_message_html', 'status')
-    readonly_fields = ('service', 'created', 'user', 'status','status_message_html')
+    readonly_fields = ('service', 'created', 'user', 'status',
+                       'status_message_html')
     exclude = ('payload',)
 
     def has_add_permission(self, request):
@@ -44,15 +48,11 @@ class LogAdmin(admin.ModelAdmin):
     status_message_html.short_description = 'Status Message'
 
 
-
 class NotificationAdmin(admin.ModelAdmin):
     form = NotificationForm
     list_display = ('name',)
 
- 
-
 admin.site.register(Notification, NotificationAdmin)
 
-
 admin.site.register(Service, ServiceAdmin)
 admin.site.register(Log, LogAdmin)
