@@ -5,8 +5,8 @@ import os
 from celery import Celery
 from django.conf import settings
 
-os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'projectname.settings')
+os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'settings')
 
 app = Celery('ftp_deploy')
 app.config_from_object('django.conf:settings')
-app.autodiscover_tasks(settings.INSTALLED_APPS, related_name='tasks')
\ No newline at end of file
+app.autodiscover_tasks(settings.INSTALLED_APPS, related_name='tasks')
