@@ -1,14 +1,17 @@
 from django import forms
-from django.contrib.auth.models import User
 
 from crispy_forms.helper import FormHelper
-from crispy_forms.bootstrap import FormActions
-from crispy_forms.layout import Layout, Field, Submit, Div, HTML
+from crispy_forms.layout import Layout, Submit
 
 
 class LoginForm(forms.Form):
-    username = forms.CharField(widget=forms.TextInput(attrs={'placeholder': 'Username', 'required': 'required'}))
-    password = forms.CharField(widget=forms.PasswordInput(render_value=False, attrs={'placeholder': 'Password', 'required': 'required'}))
+    username = forms.CharField(
+        widget=forms.TextInput(
+            attrs={'placeholder': 'Username', 'required': 'required'}))
+    password = forms.CharField(
+        widget=forms.PasswordInput(
+            render_value=False,
+            attrs={'placeholder': 'Password', 'required': 'required'}))
 
     def __init__(self, *args, **kwargs):
         super(LoginForm, self).__init__(*args, **kwargs)
