@@ -1,11 +1,11 @@
 import json
 
-from django.views.generic.base import View, TemplateResponseMixin, TemplateView
-from django.views.generic.edit import ModelFormMixin, ProcessFormView
-from django.views.generic.detail import SingleObjectMixin, SingleObjectTemplateResponseMixin
-from django.views.generic import ListView, UpdateView, DeleteView, DetailView, CreateView, FormView
+from django.views.generic.base import View
+from django.views.generic.detail import SingleObjectMixin
+from django.views.generic import (ListView, UpdateView, DeleteView,
+                                  DetailView, CreateView)
 from django.core.urlresolvers import reverse_lazy, reverse
-from django.shortcuts import render_to_response, render
+from django.shortcuts import render_to_response
 from django.template import RequestContext
 from django.contrib import messages
 from django.db.models import Max
@@ -14,9 +14,7 @@ from django.http import HttpResponse, HttpResponseRedirect, Http404
 from braces.views import JSONResponseMixin, LoginRequiredMixin
 
 from ftp_deploy.conf import *
-from ftp_deploy.models import Service, Log, Notification
-from ftp_deploy.utils.curl import curl_connection
-from ftp_deploy.utils.core import absolute_url
+from ftp_deploy.models import Service
 from ftp_deploy.utils.repo import commits_parser
 from ftp_deploy.server.forms import ServiceForm, ServiceNotificationForm
 
@@ -26,7 +24,8 @@ class DashboardView(LoginRequiredMixin, ListView):
     """View for dashboard"""
 
     model = Service
-    queryset = Service.objects.all().select_related().order_by("status", "-log__created").annotate(date=Max('log__created'))
+    queryset = Service.objects.all().select_related().order_by(
+        "status", "-log__created").annotate(date=Max('log__created'))
     context_object_name = 'services'
     template_name = "ftp_deploy/dashboard.html"
     paginate_by = 25
@@ -35,7 +34,8 @@ class DashboardView(LoginRequiredMixin, ListView):
         services = self.get_queryset()
         if self.request.POST['services']:
             services = services.filter(pk=self.request.POST['services'])
-        return render_to_response('ftp_deploy/service/list.html', locals(), context_instance=RequestContext(request))
+        return render_to_response('ftp_deploy/service/list.html', locals(),
+                                  context_instance=RequestContext(request))
 
 
 class ServiceManageView(LoginRequiredMixin, DetailView):
@@ -49,7 +49,8 @@ class ServiceManageView(LoginRequiredMixin, DetailView):
     def get_context_data(self, **kwargs):
         context = super(ServiceManageView, self).get_context_data(**kwargs)
         context['recent_logs'] = self.object.log_set.all()[:15]
-        context['fail_logs'] = self.object.log_set.filter(status=0).filter(skip=0)
+        context['fail_logs'] = self.object.log_set.filter(
+            status=0).filter(skip=0)
         return context
 
 
@@ -61,13 +62,15 @@ class ServiceAddView(LoginRequiredMixin, CreateView):
     template_name = "ftp_deploy/service/form.html"
 
     def form_valid(self, form):
-        messages.add_message(self.request, messages.SUCCESS, 'Service has been added.')
+        messages.add_message(self.request, messages.SUCCESS,
+                             'Service has been added.')
         return super(ServiceAddView, self).form_valid(form)
 
     def get_success_url(self):
         self.object.check()
         self.object.save()
-        return reverse('ftpdeploy_service_manage', kwargs={'pk': self.object.pk})
+        return reverse('ftpdeploy_service_manage',
+                       kwargs={'pk': self.object.pk})
 
 
 class ServiceEditView(LoginRequiredMixin, UpdateView):
@@ -80,11 +83,13 @@ class ServiceEditView(LoginRequiredMixin, UpdateView):
     def form_valid(self, form):
         self.object.check()
         self.object.save()
-        messages.add_message(self.request, messages.SUCCESS, 'Service has been updated.')
+        messages.add_message(self.request, messages.SUCCESS,
+                             'Service has been updated.')
         return HttpResponseRedirect(self.get_success_url())
 
     def get_success_url(self):
-        return reverse('ftpdeploy_service_manage', kwargs={'pk': self.kwargs['pk']})
+        return reverse('ftpdeploy_service_manage',
+                       kwargs={'pk': self.kwargs['pk']})
 
 
 class ServiceDeleteView(LoginRequiredMixin, DeleteView):
@@ -96,11 +101,13 @@ class ServiceDeleteView(LoginRequiredMixin, DeleteView):
     template_name = "ftp_deploy/service/delete.html"
 
     def delete(self, request, *args, **kwargs):
-        messages.add_message(request, messages.SUCCESS, 'Service has been removed.')
+        messages.add_message(request, messages.SUCCESS,
+                             'Service has been removed.')
         return super(ServiceDeleteView, self).delete(request, *args, **kwargs)
 
 
-class ServiceStatusView(JSONResponseMixin, LoginRequiredMixin, SingleObjectMixin, View):
+class ServiceStatusView(JSONResponseMixin, LoginRequiredMixin,
+                        SingleObjectMixin, View):
 
     """View for update(save) and check service status"""
 
@@ -114,13 +121,16 @@ class ServiceStatusView(JSONResponseMixin, LoginRequiredMixin, SingleObjectMixin
 
         if response == 'list':
             services = [service]
-            return render_to_response('ftp_deploy/service/list.html', locals(), context_instance=RequestContext(request))
+            return render_to_response('ftp_deploy/service/list.html', locals(),
+                                      context_instance=RequestContext(request))
 
         if response == 'manage':
             manage_view = ServiceManageView()
             manage_view.object = service
             context = manage_view.get_context_data()
-            return render_to_response('ftp_deploy/service/manage.html', context, context_instance=RequestContext(request))
+            return render_to_response(
+                'ftp_deploy/service/manage.html',
+                context, context_instance=RequestContext(request))
 
         if response == 'json':
             context = {
@@ -165,8 +175,8 @@ class ServiceRestoreView(LoginRequiredMixin, DetailView):
         context['payload']['commits'] = commits
         context['payload'] = json.dumps(context['payload'])
 
-        context['files_added'], context['files_modified'], context['files_removed'] = commits_parser(commits,service.repo_source).file_diff()
-        context['commits_info'] = commits_parser(commits,service.repo_source).commits_info()
+        context['files_added'], context['files_modified'], context['files_removed'] = commits_parser(commits, service.repo_source).file_diff()
+        context['commits_info'] = commits_parser(commits, service.repo_source).commits_info()
 
         return context
 
@@ -174,18 +184,22 @@ class ServiceRestoreView(LoginRequiredMixin, DetailView):
         if self.get_object().lock():
             return HttpResponse(status=500)
 
-        return HttpResponse(reverse('ftpdeploy_deploy', kwargs={'secret_key':self.get_object().secret_key}))
+        return HttpResponse(
+            reverse('ftpdeploy_deploy',
+                    kwargs={'secret_key': self.get_object().secret_key}))
 
 
-class ServiceNotificationView(LoginRequiredMixin,  UpdateView):
+class ServiceNotificationView(LoginRequiredMixin, UpdateView):
 
     model = Service
     form_class = ServiceNotificationForm
     template_name = "ftp_deploy/notification/notification-modal.html"
 
     def form_valid(self, form):
-        messages.add_message(self.request, messages.SUCCESS, 'Service notification has been updated.')
+        messages.add_message(self.request, messages.SUCCESS,
+                             'Service notification has been updated.')
         return super(ServiceNotificationView, self).form_valid(form)
 
     def get_success_url(self):
-        return reverse('ftpdeploy_service_manage', kwargs={'pk': self.kwargs['pk']})
+        return reverse('ftpdeploy_service_manage',
+                       kwargs={'pk': self.kwargs['pk']})
